@@ -460,13 +460,19 @@ class Storage(storage.Storage):
 
         activity = stuff.parse_activity_input(activity_name)
 
-        tags = [tag.strip() for tag in tags.split(",") if tag.strip()]  # split by comma
+        # make sure that we do have an activity name after parsing
+        if not activity.activity_name:
+            return
 
         # explicitly stated takes precedence
         activity.description = description or activity.description
 
+        tags = [tag.strip() for tag in tags.split(",") if tag.strip()]  # split by comma
+        tags = tags or activity.tags # explicitly stated tags take priority
+
         tags = self.get_tag_ids(tags) #this will create any missing tags too
 
+
         if category_name:
             activity.category_name = category_name
         if description:
@@ -922,7 +928,7 @@ class Storage(storage.Storage):
 
         """upgrade DB to hamster version"""
         version = self.fetchone("SELECT version FROM version")["version"]
-        current_version = 6
+        current_version = 7
 
         if version < 2:
             """moving from fact_date, fact_time to start_time, end_time"""
@@ -1102,6 +1108,19 @@ class Storage(storage.Storage):
             self.execute("CREATE INDEX idx_fact_tags_fact ON fact_tags(fact_id)")
             self.execute("CREATE INDEX idx_fact_tags_tag ON fact_tags(tag_id)")
 
+
+        if version < 7:
+            self.execute("""CREATE TABLE increment_facts (id integer primary key autoincrement,
+                                                          activity_id integer,
+                                                          start_time timestamp,
+                                                          end_time timestamp,
+                                                          description varchar2)""")
+            self.execute("""INSERT INTO increment_facts(id, activity_id, start_time, end_time, description)
+                                 SELECT id, activity_id, start_time, end_time, description from facts""")
+            self.execute("DROP table facts")
+            self.execute("ALTER TABLE increment_facts RENAME TO facts")
+
+
         # at the happy end, update version number
         if version < current_version:
             #lock down current version
